{# Copyright 2024 Louis Paternault

This file is part of pdfimpose-web.

Pdfimpose-web is free software: you can redistribute it and/or modify it
under the terms of the GNU Affero General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

Pdfimpose-web is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
details.

You should have received a copy of the GNU Affero General Public License
along with pdfimpose-web. If not, see <https://www.gnu.org/licenses/>.
-#}

<p>{% trans -%}
  This command only perform imposition of the front of your fanzine. It is your job to print the poster on the back.
{%- endtrans %}</p>

<ol>
  <li>{% trans -%}
    Print the resulting PDF one-sided.
  {%- endtrans %}</li>
  <li>{% trans -%}
    Cut the paper between the medium pages, as shown above.
  {%- endtrans %}</li>
  <li>{% trans -%}
    Fold the paper by (1) placing pages 1 and 2 back to back, and (2) placing each even page against the next one.
  {%- endtrans %}</li>
</ol>
