/* Copyright 2024 Louis Paternault
 *
 * This file is part of pdfimpose-web.
 *
 * Pdfimpose-web is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Affero General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 *
 * Pdfimpose-web is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with pdfimpose-web. If not, see <https://www.gnu.org/licenses/>.
 */

#upload-label {
    cursor: pointer;
    transition: background .2s ease-in-out, border .2s ease-in-out;
    border-style: dashed;
}

#upload-label:hover,
#upload-label.drag-active {
    background: #eee;
    border-color: #111;
}

fieldset {
    border: #dee2e6 solid 1pt;
    border-radius: 10pt;
    margin: 10pt 0pt;
    padding: 0pt 10pt;
}

#logo {
    height: 2em;
}
