{# Copyright 2024-2025 Louis Paternault

This file is part of pdfimpose-web.

Pdfimpose-web is free software: you can redistribute it and/or modify it
under the terms of the GNU Affero General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

Pdfimpose-web is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
details.

You should have received a copy of the GNU Affero General Public License
along with pdfimpose-web. If not, see <https://www.gnu.org/licenses/>.
-#}

<!DOCTYPE html>
<html lang="{{ lang }}">
    <head>
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <title>{% block title %}{% trans %}pdfimpose.it — Impose your PDF files!{% endtrans %}{% endblock %}</title>

        <!-- meta -->
        <meta name="description" content="{% block description %}{% trans %}Impose your PDFs online for free!{% endtrans %}{% endblock %}">
        <meta name="author" content="Louis Paternault">
        <meta name="fediverse:creator" content="@pdfimpose@floss.social">

        <!-- Generated using https://realfavicongenerator.net -->
        <link rel="apple-touch-icon" sizes="180x180" href="{{ url_for('static', filename='apple-touch-icon.png') }}">
        <link rel="icon" type="image/png" sizes="32x32" href="{{ url_for('static', filename='favicon-32x32.png') }}">
        <link rel="icon" type="image/png" sizes="16x16" href="{{ url_for('static', filename='favicon-16x16.png') }}">
        <link rel="manifest" href="{{ url_for('static', filename='site.webmanifest') }}">
        <link rel="mask-icon" href="{{ url_for('static', filename='safari-pinned-tab.svg') }}" color="#5bbad5">
        <link rel="shortcut icon" href="{{ url_for('static', filename='favicon.ico') }}">
        <meta name="msapplication-TileColor" content="#da532c">
        <meta name="msapplication-config" content="{{ url_for('static', filename='browserconfig.xml') }}">
        <meta name="theme-color" content="#ffffff">

        <!-- Bootstrap -->
        <link href="{{ url_for('static', filename='bootstrap/bootstrap.min.css') }}" rel="stylesheet" >

        <!-- mon template.css -->
        <link rel="stylesheet" href="{{ url_for('static', filename='style.css') }}" type="text/css"  media="screen">

    </head>
    <body>
        <nav class="navbar navbar-expand-sm bg-primary" data-bs-theme="dark">
            <div class="container-fluid">
                <a class="navbar-brand" href="/"><img id="logo" src="{{ url_for('static', filename='logo.png') }}" alt="" >pdfimpose.it</a>
                <button class="navbar-toggler" type="button" data-bs-toggle="collapse" data-bs-target="#navbarColor01" aria-controls="navbarColor01" aria-expanded="false" aria-label="Toggle navigation">
                    <span class="navbar-toggler-icon"></span>
                </button>
                <div class="collapse navbar-collapse" id="navbarColor01">
                    <ul class="navbar-nav me-auto">
                        <li class="nav-item">
                            <a class="nav-link" href="#faq">{% trans %}FAQ{% endtrans %}</a>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" href="#about">{% trans %}About{% endtrans %}</a>
                        </li>
                    </ul>
                    <ul class="navbar-nav flex-wrap">
                        <li class="nav-item dropdown">
                            <button class="btn btn-link nav-link dropdown-toggle" title="{% trans %}Select language{% endtrans %}" type="button" data-bs-toggle="dropdown" aria-expanded="false">
                                <img alt="Traslate logo" class="navbar-nav-svg" width="32" src="{{ url_for('static', filename='bootstrap/translate.svg') }}" >
                            </button>
                            <ul class="dropdown-menu">
                                {% for key, display in languages.items() %}
                                <li>
                                    <a class="dropdown-item" href="?language={{ key }}">{{ display.capitalize() }}</a>
                                </li>
                                {% endfor %}
                            </ul>
                        </li>
                        <li class="nav-item">
                            <a class="nav-link" href="https://floss.social/@pdfimpose" target="_blank" rel="noopener">
                              <img alt="Mastodon logo" class="navbar-nav-svg" width="32" src="{{ url_for('static', filename='bootstrap/mastodon.svg') }}" >
                            </a>
                        </li>
                    </ul>
                </div>
            </div>
        </nav>

        {% block body %}{% endblock %}

        <footer class="text-center footer mx-5">
          &copy; 2024-2025 &#x2764;&#xFE0F; <a href="mailto:{% trans %}contact(at)pdfimpose(dot)it{% endtrans %}">Louis Paternault</a> — <a rel="me" href="https://floss.social/@pdfimpose"><img src="{{ url_for("static", filename="mastodon.svg") }}" alt="Logo Mastodon" height="18"> {% trans %}Follow us on Mastodon!{% endtrans %}</a>
            <br>
            {% if stat.files is defined and stat.size is defined and stat.year is defined %}
            {% trans files=stat.files, size=stat.size, year=stat.year %}More than {{ files }} files ({{ size }}) imposed since {{ year }}!{% endtrans %}
            <br>
            {% endif %}
            {% trans %}Built with <a href="https://flask.palletsprojects.com">Flask</a>, with <a href="https://getbootstrap.com">Bootstrap</a>, and hosted at <a href="https://www.pythonanywhere.com">pythonanywhere</a>.{% endtrans %}
        </footer>

        <script src="{{ url_for('static', filename='bootstrap/bootstrap.bundle.min.js') }}" ></script>
    </body>
</html>

