{# Copyright 2024 Louis Paternault

This file is part of pdfimpose-web.

Pdfimpose-web is free software: you can redistribute it and/or modify it
under the terms of the GNU Affero General Public License as published by the
Free Software Foundation, either version 3 of the License, or (at your
option) any later version.

Pdfimpose-web is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU Affero General Public License for more
details.

You should have received a copy of the GNU Affero General Public License
along with pdfimpose-web. If not, see <https://www.gnu.org/licenses/>.
-#}

<section>
    <h1 id="about">{% trans %}About{% endtrans %}</h1>
    <p>
    {% trans -%}
    This website is a free software, distributed under the <a href="https://www.gnu.org/licenses/agpl-3.0">GNU Affero General Public licence</a>, version 3 or any later version. You can download the code powering it at <a href="https://framagit.org/spalax/pdfimpose-web">Framagit</a> to review it, study it, change it, download it, run it…
    {%- endtrans %}
    </p>

    <p>
    {% trans -%}
    This website is built on top of <a href="https://framagit.org/spalax/pdfimpose">pdfimpose</a> and <a href="https://framagit.org/spalax/pdfautonup">pdfautonup</a>, which can be used offline.
    {%- endtrans %}
    </p>

    <p>
    {% trans -%}
    Contact: <a href="mailto:contact(at)pdfimpose(dot)it">contact(at)pdfimpose(dot)it</a>.
    {%- endtrans %}
    </p>
</section>
